@@ -554,10 +554,10 @@ class RubyCodeParser:
                         j += 1
 
 
-                print(f'var = {var}')
+                # print(f'var = {var}')
                 var = self._check_snake_case_format(var, isScreaming_case=False, isExclamationMark=False, isQuestionMark=False, isFile=False)
 
-                print(f'value_with_rovno = {value_with_rovno}')
+                # print(f'value_with_rovno = {value_with_rovno}')
 
                 list_vars_in_scope.append(var + value_with_rovno)
 
@@ -1116,11 +1116,11 @@ class RubyCodeParser:
         if '=' not in chars:
             return ''
 
-        print(f'chars = {chars}')
+        # print(f'chars = {chars}')
 
         i = chars.index('=')
 
-        print(f'i = {i}')
+        # print(f'i = {i}')
 
         for j in range(i, len(chars)):
             res += chars[j]
